import { Injectable } from '@angular/core';
import { HttpClient, HttpResponse } from '@angular/common/http';
import { Observable } from 'rxjs';

import { SERVER_API_URL } from 'app/app.constants';
import { createRequestOption, SearchWithPagination } from 'app/shared/util/request-util';
import { ISavedSearches } from 'app/shared/model/saved-searches.model';

type EntityResponseType = HttpResponse<ISavedSearches>;
type EntityArrayResponseType = HttpResponse<ISavedSearches[]>;

@Injectable({ providedIn: 'root' })
export class SavedSearchesService {
  public resourceUrl = SERVER_API_URL + 'api/saved-searches';
  public resourceSearchUrl = SERVER_API_URL + 'api/_search/saved-searches';

  constructor(protected http: HttpClient) {}

  create(savedSearches: ISavedSearches): Observable<EntityResponseType> {
    return this.http.post<ISavedSearches>(this.resourceUrl, savedSearches, { observe: 'response' });
  }

  update(savedSearches: ISavedSearches): Observable<EntityResponseType> {
    return this.http.put<ISavedSearches>(this.resourceUrl, savedSearches, { observe: 'response' });
  }

  find(id: number): Observable<EntityResponseType> {
    return this.http.get<ISavedSearches>(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

  query(req?: any): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<ISavedSearches[]>(this.resourceUrl, { params: options, observe: 'response' });
  }

  delete(id: number): Observable<HttpResponse<{}>> {
    return this.http.delete(`${this.resourceUrl}/${id}`, { observe: 'response' });
  }

  search(req: SearchWithPagination): Observable<EntityArrayResponseType> {
    const options = createRequestOption(req);
    return this.http.get<ISavedSearches[]>(this.resourceSearchUrl, { params: options, observe: 'response' });
  }
}
